%define anolis_release 3
%global _lto_cflags %%{nil}

Name:           protobuf-c
Version:        1.4.1
Release:        %{anolis_release}%{?dist}
Summary:        C bindings for Google's Protocol Buffers

License:        BSD
URL:            https://github.com/protobuf-c/protobuf-c
Source0:        https://github.com/protobuf-c/protobuf-c/releases/download/v%{version}/%{name}-%{version}.tar.gz 

BuildRequires:  make gcc-c++
BuildRequires:  protobuf protobuf-devel
Requires:       pkgconfig(protobuf)

%description
Protobuf, short for Protocol Buffers, is a data serialization protocol. It was
developed by Google and was released as an open-source project in 2008. It is
designed to provide a simple and efficient way to serialize structured data for
communication between different systems.

Protobuf uses a language-neutral data format that can be used to serialize data
in a variety of programming languages such as C++, Java, Python, and Go. This
allows developers to easily share data between different systems written in
different languages.

The main advantages of using Protobuf are:

Efficiency: Protobuf generates smaller and faster messages than other
serialization formats such as XML and JSON. This is because Protobuf uses binary
encoding of data.

Flexibility: Protobuf provides a flexible schema definition language that
allows developers to define complex data structures such as nested objects and
arrays.

Interoperability: Protobuf provides language-neutral data format that can be
used by different systems written in different languages.

Extensibility: Protobuf allows developers to add new fields to the schema
without breaking compatibility with existing systems.

The basic concept of Protobuf is that data is defined in a .proto file, which
is a plain text file that contains the schema definition for the data. The
schema definition includes the data types, fields, and message formats. Once
the schema is defined, a code generator is used to generate source code for the
desired programming language.

Protobuf messages are composed of fields, each with a unique identifier and a
data type. The data types include basic types such as integers, booleans, and
strings, as well as complex types such as nested objects and arrays.

Protobuf messages can be encoded and decoded using the provided library for the
desired programming language. The encoded message can then be sent over the
network or saved to disk.

In summary, Protobuf is a simple and efficient way to serialize structured
data for communication between different systems. Its efficiency, flexibility,
interoperability, and extensibility make it a popular choice for developers who
need to share data between different systems written in different languages.

Protobuf-c provides a code generator and run-time
libraries that allow developers to use Protocol Buffers in pure C, without
the need for C++. The code generator takes a Protocol Buffer description file
(usually with a .proto extension) as input and generates C language source
code that can be compiled into the user's project. The generated code includes
functions to serialize and deserialize Protocol Buffer messages, as well as
utilities for working with field values, arrays, and other data structures. The
run-time libraries provide the necessary infrastructure to support the generated
code at run-time, including memory allocation, I/O, and error handling.
Protobuf-c is designed to be lightweight and portable, making it a popular
choice for projects that require high-performance serialization and
deserialization of structured data in C.

%package compiler
Summary:        Protocol Buffers C compiler
Requires:       %{name} = %{version}-%{release}

%description compiler
This package contains a modified version of the Protocol Buffers
compiler for the C programming language called protoc-c.

%package devel
Summary:        Protocol Buffers C headers and libraries
Requires:       %{name} = %{version}-%{release}
Requires:       %{name}-compiler = %{version}-%{release}

%description devel
This package contains protobuf-c headers and libraries.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%prep
%autosetup

%build
%configure --disable-static
%make_build

%check
make check

%install
rm -rf $RPM_BUILD_ROOT
%make_install
rm -f $RPM_BUILD_ROOT/%{_libdir}/libprotobuf-c.la

%generate_compatibility_deps

%files
%dir %{abidir}
%{_libdir}/libprotobuf-c.so.*
%{abidir}/libprotobuf-c.dump
%license LICENSE

%files compiler
%{_bindir}/protoc-c
%{_bindir}/protoc-gen-c

%files devel
%dir %{_includedir}/google
%{_includedir}/protobuf-c/
%{_includedir}/google/protobuf-c/
%{_libdir}/libprotobuf-c.so
%{_libdir}/pkgconfig/libprotobuf-c.pc

%files doc
%doc TODO ChangeLog

%changelog
* Wed Apr 12 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.4.1-3
- Optimize the spec

* Wed Mar 08 2023 Xuchun Shang <xuchun.shang@linux.alibaba.com> - 1.4.1-2
- Add abi file

* Thu Sep 22 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.4.1-1
- update to 1.4.1

* Tue Mar  8 2022 forrest_ly <flin@linux.alibaba.com> - 1.4.0-1
- Init for Anolis OS 23
